@@ -40,31 +40,33 @@
 
 #[cfg(test)]
 mod integration {
-    use assert_cli::Assert;
+    use assert_cmd::Command;
+    use predicates::prelude::*;
     use std::path;
 
-    fn sqv(keyring: &str, sig: &str) -> Assert {
-        Assert::cargo_binary("sqv")
-            .current_dir(path::Path::new("tests").join("data"))
-            .with_args(
+    fn sqv(keyring: &str, sig: &str) -> Command {
+        let mut cmd = Command::cargo_bin("sqv").expect("have sqv");
+        cmd.current_dir(path::Path::new("tests").join("data"))
+            .args(
                 &["--keyring",
                   &format!("revoked-key-cert-{}.pgp", keyring),
                   &format!("revoked-key-sig-{}.pgp", sig),
-                  "msg.txt"])
+                  "msg.txt"]);
+        cmd
     }
 
     /// Tests flavor 0, primary key signs and is revoked.
-    fn f0(keyring: &str, sig: &str) -> Assert {
+    fn f0(keyring: &str, sig: &str) -> Command {
         sqv(keyring, sig)
     }
 
     /// Tests flavor 1, subkey signs and primary key is revoked.
-    fn f1(keyring: &str, sig: &str) -> Assert {
+    fn f1(keyring: &str, sig: &str) -> Command {
         sqv(keyring, &format!("{}.sk", sig))
     }
 
     /// Tests flavor 2, subkey signs and is revoked.
-    fn f2(keyring: &str, sig: &str) -> Assert {
+    fn f2(keyring: &str, sig: &str) -> Command {
         sqv(&format!("{}.sk", keyring), &format!("{}.sk", sig))
     }
 
@@ -72,13 +74,13 @@ mod integration {
     #[test]
     fn not_revoked() {
         let c = "not-revoked";
-        f0(c, "t0").fails().unwrap();
+        f0(c, "t0").assert().failure();
         f0(c, "t1-t2").unwrap();
         f0(c, "t2-t3").unwrap();
         f0(c, "t3-now").unwrap();
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
         f1(c, "t2-t3").unwrap();
         f1(c, "t3-now").unwrap();
 
@@ -89,96 +91,96 @@ mod integration {
     #[test]
     fn revoked_no_subpacket() {
         let c = "revoked-no_subpacket";
-        f0(c, "t0").fails().unwrap();
-        f0(c, "t1-t2").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t0").assert().failure();
+        f0(c, "t1-t2").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f1(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f1(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f2(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f2(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
     }
 
     #[test]
     fn revoked_unspecified() {
         let c = "revoked-unspecified";
-        f0(c, "t0").fails().unwrap();
-        f0(c, "t1-t2").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t0").assert().failure();
+        f0(c, "t1-t2").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f1(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f1(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f2(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f2(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
     }
 
     #[test]
     fn revoked_compromised() {
         let c = "revoked-compromised";
-        f0(c, "t0").fails().unwrap();
-        f0(c, "t1-t2").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t0").assert().failure();
+        f0(c, "t1-t2").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f1(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f1(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f2(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f2(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
     }
 
     #[test]
     fn revoked_private() {
         let c = "revoked-private";
-        f0(c, "t0").fails().unwrap();
-        f0(c, "t1-t2").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t0").assert().failure();
+        f0(c, "t1-t2").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f1(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f1(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f2(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f2(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
     }
 
     #[test]
     fn revoked_unknown() {
         let c = "revoked-unknown";
-        f0(c, "t0").fails().unwrap();
-        f0(c, "t1-t2").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f0(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t0").assert().failure();
+        f0(c, "t1-t2").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f0(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f1(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f1(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
-        f2(c, "t3-now").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
+        f2(c, "t3-now").assert().failure().stderr(predicate::str::contains("revoked"));
     }
 
     /// The soft revocation reasons.  Only the signature dated prior
@@ -187,38 +189,38 @@ mod integration {
     #[test]
     fn revoked_superseded() {
         let c = "revoked-superseded";
-        f0(c, "t0").fails().unwrap();
+        f0(c, "t0").assert().failure();
         f0(c, "t1-t2").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f0(c, "t3-now").unwrap();
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f1(c, "t3-now").unwrap();
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f2(c, "t3-now").unwrap();
     }
 
     #[test]
     fn revoked_key_retired() {
         let c = "revoked-key_retired";
-        f0(c, "t0").fails().unwrap();
+        f0(c, "t0").assert().failure();
         f0(c, "t1-t2").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f0(c, "t3-now").unwrap();
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f1(c, "t3-now").unwrap();
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f2(c, "t3-now").unwrap();
     }
 
@@ -226,19 +228,19 @@ mod integration {
     #[test]
     fn revoked_uid_retired() {
         let c = "revoked-uid_retired";
-        f0(c, "t0").fails().unwrap();
+        f0(c, "t0").assert().failure();
         f0(c, "t1-t2").unwrap();
-        f0(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f0(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f0(c, "t3-now").unwrap();
 
-        f1(c, "t0").fails().unwrap();
-        f1(c, "t1-t2").fails().unwrap();
-        f1(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f1(c, "t0").assert().failure();
+        f1(c, "t1-t2").assert().failure();
+        f1(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f1(c, "t3-now").unwrap();
 
-        f2(c, "t0").fails().unwrap();
-        f2(c, "t1-t2").fails().unwrap();
-        f2(c, "t2-t3").fails().and().stderr().contains("revoked").unwrap();
+        f2(c, "t0").assert().failure();
+        f2(c, "t1-t2").assert().failure();
+        f2(c, "t2-t3").assert().failure().stderr(predicate::str::contains("revoked"));
         f2(c, "t3-now").unwrap();
     }
 }
@@ -248,7 +250,6 @@ mod integration {
 #[allow(dead_code)]
 fn create_key() {
     use std::fs::File;
-    use std::convert::TryFrom;
     use sequoia_openpgp::{
         Cert,
         Packet,
@@ -276,10 +277,10 @@ fn create_key() {
     use chrono::offset::TimeZone;
 
     let msg = b"Hello, World";
-    let t0 = chrono::offset::Utc.timestamp(1483228800, 0); // 2017-01-01
-    let t1 = chrono::offset::Utc.timestamp(1514764800, 0); // 2018-01-01
-    let t2 = chrono::offset::Utc.timestamp(1546300800, 0); // 2019-01-01
-    let t3 = chrono::offset::Utc.timestamp(1577836800, 0); // 2020-01-01
+    let t0 = chrono::offset::Utc.timestamp_opt(1483228800, 0).unwrap(); // 2017-01-01
+    let t1 = chrono::offset::Utc.timestamp_opt(1514764800, 0).unwrap(); // 2018-01-01
+    let t2 = chrono::offset::Utc.timestamp_opt(1546300800, 0).unwrap(); // 2019-01-01
+    let t3 = chrono::offset::Utc.timestamp_opt(1577836800, 0).unwrap(); // 2020-01-01
     let f1: f32 = 0.4; // Chosen by fair dice roll.
     let f2: f32 = 0.7; // Likewise.
     let t12 = t1 + chrono::Duration::days((300.0 * f1) as i64);
